# Flask-RESTy-Tenants [![Travis][build-badge]][build] [![PyPI][pypi-badge]][pypi]

Multitenant authorization for [Flask-RESTy](https://flask-resty.readthedocs.io/).

[![Codecov][codecov-badge]][codecov]

[build-badge]: https://img.shields.io/travis/4Catalyzer/flask-resty-tenants/master.svg
[build]: https://travis-ci.org/4Catalyzer/flask-resty-tenants
[pypi-badge]: https://img.shields.io/pypi/v/Flask-RESTy-Tenants.svg
[pypi]: https://pypi.python.org/pypi/Flask-RESTy-Tenants
[codecov-badge]: https://img.shields.io/codecov/c/github/4Catalyzer/flask-resty-tenants/master.svg
[codecov]: https://codecov.io/gh/4Catalyzer/flask-resty-tenants
